@@ -63,15 +63,30 @@ def print_results(results):
     """
     table = []
     added_list = []
-    headers = ["Id", "Package", "CWE", "Severity", "Score", "Description"]
+    headers = [
+        "Id",
+        "Package",
+        "Affected Version",
+        "CWE",
+        "Severity",
+        "Score",
+        "Description",
+    ]
     for res in results:
         vuln_occ_dict = res.to_dict()
         id = vuln_occ_dict.get("id")
         if id not in added_list:
             package_issue = res.package_issue
+            full_pkg = package_issue.affected_location.package
+            if package_issue.affected_location.vendor:
+                full_pkg = "{}:{}".format(
+                    package_issue.affected_location.vendor,
+                    package_issue.affected_location.package,
+                )
             table.append(
                 [
                     id,
+                    full_pkg,
                     package_issue.affected_location.version,
                     vuln_occ_dict.get("problem_type"),
                     vuln_occ_dict.get("severity"),
@@ -80,12 +95,12 @@ def print_results(results):
                 ]
             )
             added_list.append(id)
-    print(tabulate(table, headers, tablefmt="grid"), flush=True)
+    print(tabulate(table, headers, tablefmt="grid"))
 
 
 def main():
     args = build_args()
-    print(at_logo, flush=True)
+    print(at_logo)
     LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
     if args.cache:
         for s in [GitHubSource(), NvdSource()]:
