@@ -267,11 +267,13 @@ class CvssV3(object):
 
 class VulnerabilityLocation(object):
     cpe_uri: str
+    vendor: str
     package: str
     version: str
 
-    def __init__(self, cpe_uri, package, version):
+    def __init__(self, cpe_uri, vendor, package, version):
         self.cpe_uri = cpe_uri
+        self.vendor = vendor
         self.package = package
         self.version = version
 
@@ -291,7 +293,9 @@ class VulnerabilityLocation(object):
             else:
                 version = min_affected_version + "-" + max_affected_version
         if parts:
-            return VulnerabilityLocation(cpe_uri, parts.group(2), version)
+            return VulnerabilityLocation(
+                cpe_uri, parts.group("vendor"), parts.group("package"), version
+            )
         else:
             return None
 
