@@ -8,16 +8,16 @@ This module fetches the recent security advisories from GitHub and stores them i
 - Full description (description) is ignored for now
 
 """
-import json
 import logging
 import os
 import re
 
 import requests
+import ujson
 
 import vdb.lib.config as config
 from vdb.lib.nvd import NvdSource
-from vdb.lib.utils import get_default_cve_data
+from vdb.lib.utils import get_default_cve_data, fix_text
 
 logging.basicConfig(
     level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
@@ -131,22 +131,35 @@ class GitHubSource(NvdSource):
         < 0.1.11 denotes a version range up to, but excluding, the specified version
         >= 4.3.0, < 4.3.5 denotes a version range with a known minimum and maximum version.
         >= 0.0.1 denotes a version range with a known minimum, but no known maximum
+        > 2.1.0, < 2.1.8
+        > 2.0.0, <= 2.0.14
         """
-        version_start = ""
-        version_end = "*"
+        version_start_including = ""
+        version_end_including = ""
+        version_start_excluding = ""
+        version_end_excluding = ""
         if version_str.startswith("= "):
-            version_end = version_str.replace("= ", "")
+            version_end_including = version_str.replace("= ", "")
         elif version_str.startswith("<= "):
-            version_end = version_str.replace("<= ", "")
-        # FIXME: This could lead to more false positives
+            version_end_including = version_str.replace("<= ", "")
         elif version_str.startswith("< "):
-            version_end = version_str.replace("< ", "")
+            version_end_excluding = version_str.replace("< ", "")
         elif version_str.startswith(">= "):
-            version_str = version_str.replace(">= ", "")
+            version_start_including = version_str.replace(">= ", "").split(", ")[0]
+        elif version_str.startswith("> "):
+            version_start_excluding = version_str.replace("> ", "").split(", ")[0]
+        if version_end_excluding == "":
             tmpA = version_str.split(", ")
-            version_start = tmpA[0]
-            version_end = tmpA[len(tmpA) - 1].replace("< ", "").replace("<= ", "")
-        return version_start, version_end
+            if tmpA[len(tmpA) - 1].startswith("<= "):
+                version_end_including = tmpA[len(tmpA) - 1].replace("<= ", "")
+            elif tmpA[len(tmpA) - 1].startswith("< "):
+                version_end_excluding = tmpA[len(tmpA) - 1].replace("< ", "")
+        return (
+            version_start_including,
+            version_end_including,
+            version_start_excluding,
+            version_end_excluding,
+        )
 
     def convert(self, cve_data):
         """Convert the GitHub advisory data into Vulnerability objects
@@ -184,7 +197,12 @@ class GitHubSource(NvdSource):
                     vendor = tmpA[0]
                     product = tmpA[len(tmpA) - 1]
                 version = p["vulnerableVersionRange"]
-                version_start, version_end = self.get_version_range(version)
+                (
+                    version_start_including,
+                    version_end_including,
+                    version_start_excluding,
+                    version_end_excluding,
+                ) = self.get_version_range(version)
                 severity = p["severity"]
                 score, severity, vectorString, attackComplexity = get_default_cve_data(
                     severity
@@ -193,20 +211,26 @@ class GitHubSource(NvdSource):
                     cve_id=cve_id,
                     cwe_id="UNKNOWN",
                     assigner=assigner,
-                    references=json.dumps(references),
-                    description=cve["summary"],
+                    references=ujson.dumps(references),
+                    description=fix_text(cve["summary"]),
                     vectorString=vectorString,
                     vendor=vendor.lower(),
                     product=product.lower(),
                     version="*",
-                    version_start=version_start,
-                    version_end=version_end,
+                    version_start_including=version_start_including,
+                    version_end_including=version_end_including,
+                    version_start_excluding=version_start_excluding,
+                    version_end_excluding=version_end_excluding,
                     severity=severity,
                     attackComplexity=attackComplexity,
                     score=score,
                     publishedDate=cve["publishedAt"],
                     lastModifiedDate=cve["updatedAt"],
                 )
-                vuln = NvdSource.convert_vuln(json.loads(tdata, strict=False))
-                ret_data.append(vuln)
+                try:
+                    tdata_json = ujson.loads(tdata)
+                    vuln = NvdSource.convert_vuln(tdata_json)
+                    ret_data.append(vuln)
+                except ujson.ValueError:
+                    LOG.warning(tdata)
         return ret_data, page_info
