@@ -14,7 +14,7 @@ from vdb.lib.utils import (
     get_default_cve_data,
     serialize_vuln_list,
     convert_to_occurrence,
-    fix_text
+    fix_text,
 )
 
 logging.basicConfig(
